import typer_cloup as typer


def main():
    typer.echo("Opening Typer's docs")
    typer.launch("https://typer-cloup.netlify.app")


if __name__ == "__main__":
    typer.run(main)
